// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

// resolves . and .. elements in a path array with directory names there
// must be no slashes, empty elements, or device names (c:\) in the array
// (so also no leading and trailing slashes - it does not distinguish
// relative and absolute paths)
function normalizeArray(parts, allowAboveRoot) {
  // if the path tries to go above the root, `up` ends up > 0
  var up = 0;
  for (var i = parts.length - 1; i >= 0; i--) {
    var last = parts[i];
    if (last === '.') {
      parts.splice(i, 1);
    } else if (last === '..') {
      parts.splice(i, 1);
      up++;
    } else if (up) {
      parts.splice(i, 1);
      up--;
    }
  }

  // if the path is allowed to go above the root, restore leading ..s
  if (allowAboveRoot) {
    for (; up--; up) {
      parts.unshift('..');
    }
  }

  return parts;
}

// path.normalize(path)
// posix version
function normalize(path) {
  var isPathAbsolute = isAbsolute(path),
      trailingSlash = substr(path, -1) === '/';

  // Normalize the path
  path = normalizeArray(filter(path.split('/'), function(p) {
    return !!p;
  }), !isPathAbsolute).join('/');

  if (!path && !isPathAbsolute) {
    path = '.';
  }
  if (path && trailingSlash) {
    path += '/';
  }

  return (isPathAbsolute ? '/' : '') + path;
}
// posix version
function isAbsolute(path) {
  return path.charAt(0) === '/';
}

// posix version
function join() {
  var paths = Array.prototype.slice.call(arguments, 0);
  return normalize(filter(paths, function(p, index) {
    if (typeof p !== 'string') {
      throw new TypeError('Arguments to path.join must be strings');
    }
    return p;
  }).join('/'));
}
function filter (xs, f) {
    if (xs.filter) return xs.filter(f);
    var res = [];
    for (var i = 0; i < xs.length; i++) {
        if (f(xs[i], i, xs)) res.push(xs[i]);
    }
    return res;
}

// String.prototype.substr - negative index don't work in IE8
var substr = 'ab'.substr(-1) === 'b' ?
    function (str, start, len) { return str.substr(start, len) } :
    function (str, start, len) {
        if (start < 0) start = str.length + start;
        return str.substr(start, len);
    }
;

var name = "nuxt-google-maps";
var version = "1.0.2";
var description = "A Nuxt module with vue2-google-maps";
var keywords = [
	"nuxt",
	"google-maps"
];
var main = "dist/nuxt-google-maps.umd.js";
var module$1 = "dist/nuxt-google-maps.es5.js";
var typings = "dist/types/nuxt-google-maps.d.ts";
var files = [
	"dist"
];
var author = "Gregory Bouteiller <gregory.bouteiller@niama.re>";
var repository = "https://github.com/gbouteiller/nuxt-google-maps.git";
var license = "MIT";
var engines = {
	node: ">=6.0.0"
};
var scripts = {
	prebuild: "rimraf dist",
	build: "tsc --module commonjs && rollup -c rollup.config.ts",
	start: "rollup -c rollup.config.ts -w",
	test: "jest",
	"test:watch": "jest --watch",
	"test:prod": "npm run test -- --coverage --no-cache"
};
var jest = {
	transform: {
		".(ts|tsx)": "<rootDir>/node_modules/ts-jest/preprocessor.js"
	},
	testRegex: "(/__tests__/.*|\\.(test|spec))\\.(ts|tsx|js)$",
	moduleFileExtensions: [
		"ts",
		"tsx",
		"js"
	],
	coveragePathIgnorePatterns: [
		"/node_modules/",
		"/test/"
	],
	coverageThreshold: {
		global: {
			branches: 90,
			functions: 95,
			lines: 95,
			statements: 95
		}
	},
	collectCoverage: true
};
var devDependencies = {
	"@types/jest": "^23.3.0",
	"@types/node": "^10.5.2",
	"@types/react": "^16.4.6",
	"lodash.camelcase": "^4.3.0",
	rollup: "^0.65.2",
	"rollup-plugin-commonjs": "^9.1.3",
	"rollup-plugin-copy": "^0.2.3",
	"rollup-plugin-json": "^3.0.0",
	"rollup-plugin-node-builtins": "^2.1.2",
	"rollup-plugin-node-resolve": "^3.3.0",
	"rollup-plugin-sourcemaps": "^0.4.2",
	"rollup-plugin-typescript2": "^0.17.0",
	"ts-jest": "^23.0.1",
	"ts-node": "^7.0.0",
	tslint: "^5.11.0",
	"tslint-config-prettier": "^1.13.0",
	typescript: "^3.0.3"
};
var dependencies = {
	"vue2-google-maps": "^0.10.0"
};
var _package = {
	name: name,
	version: version,
	description: description,
	keywords: keywords,
	main: main,
	module: module$1,
	typings: typings,
	files: files,
	author: author,
	repository: repository,
	license: license,
	engines: engines,
	scripts: scripts,
	jest: jest,
	devDependencies: devDependencies,
	dependencies: dependencies
};

var meta = /*#__PURE__*/Object.freeze({
  name: name,
  version: version,
  description: description,
  keywords: keywords,
  main: main,
  module: module$1,
  typings: typings,
  files: files,
  author: author,
  repository: repository,
  license: license,
  engines: engines,
  scripts: scripts,
  jest: jest,
  devDependencies: devDependencies,
  dependencies: dependencies,
  default: _package
});

function nuxtGoogleMapsModule(moduleOptions) {
    if (moduleOptions === void 0) { moduleOptions = {}; }
    var options = Object.assign({}, this.options.googleMaps || moduleOptions);
    if (options.key === undefined)
        throw new Error('[GoogleMaps Module] Required api key in configuration.');
    if (options.libraries === undefined)
        options.libraries = 'places';
    else if (Array.isArray(options.libraries))
        options.libraries = options.libraries.join(', ');
    options.autobindAllEvents = options.autobindAllEvents !== false;
    options.installComponents = options.installComponents !== false;
    this.extendBuild(function (config, _a) {
        var isClient = _a.isClient;
        if (isClient)
            return;
        var handler = function (_, request, callback) { return (/^vue2-google-maps($|\/)/.test(request) ? callback(null, false) : callback()); };
        config.externals = config.externals || {};
        Array.isArray(config.externals) ? config.externals.unshift(handler) : (config.externals['vue2-google-maps'] = handler);
    });
    this.addPlugin({ src: join(__dirname, './lib/templates/plugin.js'), options: options });
}
nuxtGoogleMapsModule['meta'] = meta;

export default nuxtGoogleMapsModule;
//# sourceMappingURL=nuxt-google-maps.es5.js.map
